@@ -8,7 +8,7 @@ class CustomDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit CustomDialog(const QStringList &items);
+    explicit CustomDialog(const QStringList &items, QDialog *parent = nullptr);
 
     QComboBox *comboBox();
 
